==> aws-cdk-lib-2.0.0-rc.20-sources.jar: software/amazon/awscdk/ICfnRuleConditionExpression.java <==
package software.amazon.awscdk;

/**
 * (experimental) Interface to specify certain functions as Service Catalog rule-specifc.
 * <p>
 * These functions can only be used in <code>Rules</code> section of template.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.31.0 (build 6fa403d)", date = "2021-09-01T10:25:51.440Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.ICfnRuleConditionExpression")
@software.amazon.jsii.Jsii.Proxy(ICfnRuleConditionExpression.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
public interface ICfnRuleConditionExpression extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.ICfnConditionExpression {

    /**
     * (experimental) This field is only needed to defeat TypeScript's structural typing.
     * <p>
     * It is never used.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    @org.jetbrains.annotations.NotNull java.lang.Boolean getDisambiguator();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.ICfnRuleConditionExpression.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * (experimental) The creation stack of this resolvable which will be appended to errors thrown during resolution.
         * <p>
         * This may return an array with a single informational element indicating how
         * to get this property populated, if it was skipped for performance reasons.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getCreationStack() {
            return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "creationStack", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
        }

        /**
         * (experimental) This field is only needed to defeat TypeScript's structural typing.
         * <p>
         * It is never used.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public final @org.jetbrains.annotations.NotNull java.lang.Boolean getDisambiguator() {
            return software.amazon.jsii.Kernel.get(this, "disambiguator", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * (experimental) Produce the Token's value at resolution time.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.Object resolve(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return software.amazon.jsii.Kernel.call(this, "resolve", software.amazon.jsii.NativeType.forClass(java.lang.Object.class), new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }

        /**
         * (experimental) Return a string representation of this resolvable object.
         * <p>
         * Returns a reversible string representation.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.String toString() {
            return software.amazon.jsii.Kernel.call(this, "toString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }

    /**
     * Internal default implementation for {@link ICfnRuleConditionExpression}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends ICfnRuleConditionExpression, software.amazon.awscdk.ICfnConditionExpression.Jsii$Default {

        /**
         * (experimental) The creation stack of this resolvable which will be appended to errors thrown during resolution.
         * <p>
         * This may return an array with a single informational element indicating how
         * to get this property populated, if it was skipped for performance reasons.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getCreationStack() {
            return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "creationStack", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
        }

        /**
         * (experimental) This field is only needed to defeat TypeScript's structural typing.
         * <p>
         * It is never used.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        default @org.jetbrains.annotations.NotNull java.lang.Boolean getDisambiguator() {
            return software.amazon.jsii.Kernel.get(this, "disambiguator", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * (experimental) Produce the Token's value at resolution time.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        default @org.jetbrains.annotations.NotNull java.lang.Object resolve(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return software.amazon.jsii.Kernel.call(this, "resolve", software.amazon.jsii.NativeType.forClass(java.lang.Object.class), new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }
    }
}

==> aws-cdk-lib-2.10.0-sources.jar: software/amazon/awscdk/ICfnRuleConditionExpression.java <==
package software.amazon.awscdk;

/**
 * Interface to specify certain functions as Service Catalog rule-specifc.
 * <p>
 * These functions can only be used in <code>Rules</code> section of template.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.52.1 (build 5ccc8f6)", date = "2022-01-29T04:34:06.874Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.$Module.class, fqn = "aws-cdk-lib.ICfnRuleConditionExpression")
@software.amazon.jsii.Jsii.Proxy(ICfnRuleConditionExpression.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface ICfnRuleConditionExpression extends software.amazon.jsii.JsiiSerializable, software.amazon.awscdk.ICfnConditionExpression {

    /**
     * This field is only needed to defeat TypeScript's structural typing.
     * <p>
     * It is never used.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.Boolean getDisambiguator();

    /**
     * A proxy class which represents a concrete javascript instance of this type.
     */
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements software.amazon.awscdk.ICfnRuleConditionExpression.Jsii$Default {
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
        }

        /**
         * The creation stack of this resolvable which will be appended to errors thrown during resolution.
         * <p>
         * This may return an array with a single informational element indicating how
         * to get this property populated, if it was skipped for performance reasons.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getCreationStack() {
            return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "creationStack", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
        }

        /**
         * This field is only needed to defeat TypeScript's structural typing.
         * <p>
         * It is never used.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public final @org.jetbrains.annotations.NotNull java.lang.Boolean getDisambiguator() {
            return software.amazon.jsii.Kernel.get(this, "disambiguator", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Produce the Token's value at resolution time.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.Object resolve(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return software.amazon.jsii.Kernel.call(this, "resolve", software.amazon.jsii.NativeType.forClass(java.lang.Object.class), new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }

        /**
         * Return a string representation of this resolvable object.
         * <p>
         * Returns a reversible string representation.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public final @org.jetbrains.annotations.NotNull java.lang.String toString() {
            return software.amazon.jsii.Kernel.call(this, "toString", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }
    }

    /**
     * Internal default implementation for {@link ICfnRuleConditionExpression}.
     */
    @software.amazon.jsii.Internal
    interface Jsii$Default extends ICfnRuleConditionExpression, software.amazon.awscdk.ICfnConditionExpression.Jsii$Default {

        /**
         * The creation stack of this resolvable which will be appended to errors thrown during resolution.
         * <p>
         * This may return an array with a single informational element indicating how
         * to get this property populated, if it was skipped for performance reasons.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.util.List<java.lang.String> getCreationStack() {
            return java.util.Collections.unmodifiableList(software.amazon.jsii.Kernel.get(this, "creationStack", software.amazon.jsii.NativeType.listOf(software.amazon.jsii.NativeType.forClass(java.lang.String.class))));
        }

        /**
         * This field is only needed to defeat TypeScript's structural typing.
         * <p>
         * It is never used.
         */
        @Override
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        default @org.jetbrains.annotations.NotNull java.lang.Boolean getDisambiguator() {
            return software.amazon.jsii.Kernel.get(this, "disambiguator", software.amazon.jsii.NativeType.forClass(java.lang.Boolean.class));
        }

        /**
         * Produce the Token's value at resolution time.
         * <p>
         * @param context This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        default @org.jetbrains.annotations.NotNull java.lang.Object resolve(final @org.jetbrains.annotations.NotNull software.amazon.awscdk.IResolveContext context) {
            return software.amazon.jsii.Kernel.call(this, "resolve", software.amazon.jsii.NativeType.forClass(java.lang.Object.class), new Object[] { java.util.Objects.requireNonNull(context, "context is required") });
        }
    }
}
